@import "@synerty/peek-plugin-base-js/src/styles/_variables";

:host {
    .hide-modal {
        display: none;
        visibility: hidden;
    }

    .page-modal-body {
        padding: 20px;
    }
}

.page-modal {
    justify-content: unset;
    margin: $general_margin_3;
}
